@@ -27,6 +27,7 @@ class ApplicationEventFilter : public QObject
 
 Q_SIGNALS:
     void applicationMouseLeave();
+    void applicationMouseEnter();
 
 protected:
     bool eventFilter(QObject *obj, QEvent *event) override
@@ -34,6 +35,9 @@ protected:
         if (event->type() == QEvent::Leave) {
             Q_EMIT applicationMouseLeave();
             return true;
+        } else if (event->type() == QEvent::Enter) {
+            Q_EMIT applicationMouseEnter();
+            return true;
         } else {
             // standard event processing
             return QObject::eventFilter(obj, event);
@@ -68,6 +72,7 @@ public:
     Q_INVOKABLE void openDocs(const QString &page);
     Q_INVOKABLE QStringList getFonts();
     Q_INVOKABLE int frameworksVersionMinor();
+    Q_INVOKABLE int qtMajorVersion();
     Q_INVOKABLE QString platformName();
     Q_INVOKABLE void raiseWindow();
 
@@ -85,6 +90,7 @@ public:
 
 Q_SIGNALS:
     void qmlApplicationMouseLeave();
+    void qmlApplicationMouseEnter();
     void error(const QString &message);
     void saveWindowGeometryAsync(QQuickWindow *window);
 
